@@ -14,11 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Unit Tests for service class
-"""
-
-from __future__ import print_function
+"""Unit Tests for service class"""
 
 import logging
 import multiprocessing
@@ -27,10 +23,10 @@ import signal
 import socket
 import time
 import traceback
+from unittest import mock
 
 import eventlet
 from eventlet import event
-import mock
 from oslotest import base as test_base
 
 from oslo_service import service
@@ -168,8 +164,8 @@ class ServiceLauncherTest(ServiceTestBase):
         # Skip ps header
         f.readline()
 
-        processes = [tuple(int(p) for p in l.strip().split()[:2])
-                     for l in f]
+        processes = [tuple(int(p) for p in line.strip().split()[:2])
+                     for line in f]
         return [p for p, pp in processes if pp == self.pid]
 
     def test_killed_worker_recover(self):
